package com.landray.kmss.sys.attachment.borrow.actions;

import com.landray.kmss.web.config.IActionConfig;
import java.util.Map;
import com.landray.kmss.common.service.IBaseService;
import com.landray.kmss.web.config.ForwardConfig;
import java.util.List;
import com.landray.kmss.util.KmssReturnPage;
import org.json.simple.JSONObject;
import com.landray.kmss.util.KmssMessages;
import com.landray.kmss.common.test.TimeCounter;
import com.landray.kmss.web.action.ActionForward;
import com.landray.kmss.common.actions.RequestContext;
import com.landray.kmss.common.forms.IExtendForm;
import com.landray.kmss.sys.attachment.borrow.forms.SysAttBorrowForm;
import javax.servlet.http.HttpServletResponse;
import com.landray.kmss.web.action.ActionForm;
import com.landray.kmss.web.action.ActionMapping;
import com.landray.kmss.util.UserUtil;
import com.landray.kmss.util.StringUtil;
import org.apache.commons.lang3.ArrayUtils;
import com.landray.kmss.sys.attachment.borrow.model.SysAttBorrow;
import com.landray.kmss.util.HQLHelper;
import com.landray.kmss.common.dao.HQLInfo;
import javax.servlet.http.HttpServletRequest;
import com.landray.kmss.sys.attachment.borrow.service.ISysAttBorrowService;
import com.landray.kmss.common.actions.ExtendAction;

public class SysAttBorrowAction extends ExtendAction
{
    private ISysAttBorrowService sysAttBorrowService;
    private static final String READ_KEY = "read";
    private static final String DOWNLOAD_KEY = "download";
    private static final String PRINT_KEY = "print";
    private static final String COPY_KEY = "copy";
    private static final String DETAIL_FORWARD = "detail";
    private static final String MY_FORWARD = "my";
    
    public ISysAttBorrowService getServiceImp(final HttpServletRequest request) {
        if (this.sysAttBorrowService == null) {
            this.sysAttBorrowService = (ISysAttBorrowService)this.getBean("sysAttBorrowService");
        }
        return this.sysAttBorrowService;
    }
    
    public void changeFindPageHQLInfo(final HttpServletRequest request, final HQLInfo hqlInfo) throws Exception {
        HQLHelper.by(request).buildHQLInfo(hqlInfo, (Class)SysAttBorrow.class);
        final String forward = request.getParameter("forward");
        hqlInfo.setOrderBy(this.getFindPageOrderBy(request, hqlInfo.getOrderBy()));
        if ("detail".equals(forward)) {
            final String[] fdAuth = request.getParameterValues("q.fdAuth");
            if (ArrayUtils.isNotEmpty((Object[])fdAuth)) {
                final StringBuffer hql = new StringBuffer();
                for (int i = 0; i < fdAuth.length; ++i) {
                    if (i == 0) {
                        hql.append("(");
                    }
                    else {
                        hql.append(" or ");
                    }
                    if ("read".equals(fdAuth[i])) {
                        hql.append("sysAttBorrow.fdReadEnable = :fdReadEnable");
                    }
                    if ("download".equals(fdAuth[i])) {
                        hql.append("sysAttBorrow.fdDownloadEnable = :fdDownloadEnable");
                    }
                    if ("print".equals(fdAuth[i])) {
                        hql.append("sysAttBorrow.fdPrintEnable = :fdPrintEnable");
                    }
                    if ("copy".equals(fdAuth[i])) {
                        hql.append("sysAttBorrow.fdCopyEnable = :fdCopyEnable");
                    }
                    if (i == fdAuth.length - 1) {
                        hql.append(")");
                    }
                }
                hqlInfo.setWhereBlock(StringUtil.linkString(hqlInfo.getWhereBlock(), " and ", hql.toString()));
                for (int i = 0; i < fdAuth.length; ++i) {
                    if ("read".equals(fdAuth[i])) {
                        hqlInfo.setParameter("fdReadEnable", (Object)true);
                    }
                    if ("download".equals(fdAuth[i])) {
                        hqlInfo.setParameter("fdDownloadEnable", (Object)true);
                    }
                    if ("print".equals(fdAuth[i])) {
                        hqlInfo.setParameter("fdPrintEnable", (Object)true);
                    }
                    if ("copy".equals(fdAuth[i])) {
                        hqlInfo.setParameter("fdCopyEnable", (Object)true);
                    }
                }
            }
            final String fdAttId = request.getParameter("attId");
            if (StringUtil.isNotNull(fdAttId)) {
                hqlInfo.setWhereBlock(StringUtil.linkString(hqlInfo.getWhereBlock(), " and ", "sysAttBorrow.fdAttId = :fdAttId"));
                hqlInfo.setParameter("fdAttId", (Object)fdAttId);
            }
            return;
        }
        final String type = request.getParameter("type");
        if ("my".equals(type)) {
            hqlInfo.setWhereBlock(StringUtil.linkString(hqlInfo.getWhereBlock(), " and ", "sysAttBorrow.fdBorrowers.fdId = :fdUserId"));
            hqlInfo.setParameter("fdUserId", (Object)UserUtil.getUser().getFdId());
        }
        hqlInfo.setDistinctType(0);
        hqlInfo.setJoinBlock(", com.landray.kmss.sys.attachment.model.SysAttMain sysAttMain");
        hqlInfo.setWhereBlock(StringUtil.linkString(hqlInfo.getWhereBlock(), " and ", "sysAttBorrow.fdAttId = sysAttMain.fdId"));
        hqlInfo.setSelectBlock("sysAttBorrow.fdId,sysAttBorrow.fdStatus,sysAttBorrow.fdBorrowEffectiveTime,sysAttBorrow.fdDuration,sysAttMain.fdFileName,sysAttMain.fdSize,sysAttMain.fdModelName");
    }
    
    public ActionForm createNewForm(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final SysAttBorrowForm sysAttBorrowForm = (SysAttBorrowForm)super.createNewForm(mapping, form, request, response);
        this.getServiceImp(request).initFormSetting((IExtendForm)form, new RequestContext(request));
        return (ActionForm)sysAttBorrowForm;
    }
    
    public ActionForward count(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-count", true, (Class)this.getClass());
        final KmssMessages messages = new KmssMessages();
        try {
            final JSONObject json = new JSONObject();
            final HQLInfo hqlInfo = new HQLInfo();
            hqlInfo.setGettingCount(true);
            final String type = request.getParameter("type");
            if ("create".equals(type)) {
                hqlInfo.setWhereBlock("sysAttBorrow.fdBorrowers.fdId =:fdBorrowerId");
                hqlInfo.setParameter("fdBorrowerId", (Object)UserUtil.getUser().getFdId());
            }
            hqlInfo.setSelectBlock("count(distinct sysAttBorrow.fdId)");
            final List<Long> count = this.getServiceImp(request).findValue(hqlInfo);
            json.put((Object)"count", (Object)count.get(0));
            request.setAttribute("lui-source", (Object)json);
        }
        catch (final Exception e) {
            messages.addError((Throwable)e);
        }
        TimeCounter.logCurrentTime("Action-count", false, (Class)this.getClass());
        if (messages.hasError()) {
            KmssReturnPage.getInstance(request).addMessages(messages).save(request);
            return this.getActionForward("failure", mapping, form, request, response);
        }
        KmssReturnPage.getInstance(request).addMessages(messages).addButton(0).save(request);
        return this.getActionForward("lui-source", mapping, form, request, response);
    }
    
    public ActionForward close(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-close", true, (Class)this.getClass());
        final KmssMessages messages = new KmssMessages();
        try {
            final String[] fdIds = request.getParameterValues("fdIds");
            if (!ArrayUtils.isEmpty((Object[])fdIds)) {
                this.getServiceImp(request).updateCloseStatus(fdIds);
            }
            final JSONObject json = new JSONObject();
            request.setAttribute("lui-source", (Object)json);
        }
        catch (final Exception e) {
            messages.addError((Throwable)e);
        }
        TimeCounter.logCurrentTime("Action-close", false, (Class)this.getClass());
        if (messages.hasError()) {
            KmssReturnPage.getInstance(request).addMessages(messages).save(request);
            return this.getActionForward("failure", mapping, form, request, response);
        }
        KmssReturnPage.getInstance(request).addMessages(messages).addButton(0).save(request);
        return this.getActionForward("lui-source", mapping, form, request, response);
    }
}
